/**
Author:  Luis Gerardo de la Fraga
Space3d: program to visualize polygons over 3D space
Copyright (C) 2002 Luis Gerardo de la Fraga

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Author's e-mail: fraga@cs.cinvestav.mx
Address: 
Seccin de Computacin. Dpto. de Ingeniera Elctrica
CINVESTAV-IPN                       
Av. Instituto Politcnico Nacional No. 2508
07300 Mxico, D.F. 
Mxico
**/

#include <QApplication>
#include <QPushButton>
#include <QGridLayout>
#include <QLabel>
#include <QFont>
#include <QString>


#include "painter.h"
#include "space3d.h"


Painter::Painter( const char *filename, QWidget *parent )
        : QWidget( parent )
{
    quit = new QPushButton( tr("Quit") );

    quit->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );

    spheres = new Space3D( filename );
	spheres -> setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
	connect( spheres, SIGNAL(changeButton()), SLOT(toButton( )) );


	light = new QComboBox;
	light -> addItem( "No Lights" ); 
	light -> addItem( "Lighting" ); 
	connect( light, SIGNAL(activated(int)), spheres, SLOT(selectLight(int)) );

	whohavelight = new QComboBox;
	whohavelight -> addItem( "To Viewer" ); 
	whohavelight -> addItem( "To Object" ); 
	connect(whohavelight,SIGNAL(activated(int)),spheres,SLOT(selLightSubject(int)) );

    // QGridLayout *grid = new QGridLayout( this, 3, 2, 5 ); //3x2, 5 pixel border
    QGridLayout *grid = new QGridLayout;
    grid->addWidget( spheres, 0, 1 );
    grid->setColumnStretch( 1, 5 );
    setLayout(grid );


	QVBoxLayout *leftBox = new QVBoxLayout;
	leftBox->addWidget( quit );
	leftBox->addWidget( light );
	leftBox->addWidget( whohavelight );
	grid->addLayout( leftBox, 0, 0 );

	angle1 = new QSpinBox;
	angle1 -> setRange( 0, 360);
	angle1 -> setSingleStep( 1 );
	angle1->setWrapping ( TRUE ); 
	connect( angle1, SIGNAL(valueChanged(int)), spheres, SLOT(angValue1(int)));
	
	QLabel *alfaLabel = new QLabel( tr("Alfa: ") );

	angle2 = new QSpinBox;
	angle2 -> setRange( 0, 360);
	angle2 -> setSingleStep( 1 );
	angle2->setWrapping ( TRUE ); 
	connect( angle2, SIGNAL(valueChanged(int)), spheres, SLOT(angValue2(int)));

	QLabel *betaLabel = new QLabel( tr("Beta: ") );
	
	angle3 = new QSpinBox;
	angle2 -> setRange( 0, 360);
	angle2 -> setSingleStep( 1 );
	angle3->setWrapping ( TRUE ); 
	connect( angle3, SIGNAL(valueChanged(int)), spheres, SLOT(angValue3(int)));

	QLabel *gamaLabel = new QLabel( tr("Gama: ") );
	gamaLabel->setText( "Gama: " );

	QGridLayout * angvals = new QGridLayout;
    angvals->addWidget( alfaLabel, 0, 0 );
    angvals->addWidget( angle1, 0, 1 );
    angvals->addWidget( betaLabel, 1, 0 );
    angvals->addWidget( angle2, 1, 1 );
    angvals->addWidget( gamaLabel, 2, 0 );
    angvals->addWidget( angle3, 2, 1 );

	grid->addLayout( angvals, 1, 0 );

	// Widgets part for animation

    initang = new QSpinBox;
	initang -> setRange( 0, 360);
	initang -> setSingleStep( 1 );
	initang -> setWrapping ( TRUE ); 
	connect( initang, SIGNAL(valueChanged(int)), spheres, SLOT(angAniVal1(int)));

    stopang = new QSpinBox;
	stopang -> setRange( 0, 360);
	stopang -> setSingleStep( 1 );
	stopang->setWrapping ( TRUE ); 
	connect( stopang, SIGNAL(valueChanged(int)), spheres, SLOT(angAniVal2(int)));

	whichAng = new QComboBox;
	whichAng -> addItem( "alfa" ); 
	whichAng -> addItem( "beta" ); 
	whichAng -> addItem( "gama" ); 
	connect( whichAng, SIGNAL(activated(int)), spheres,SLOT(selectWhichAng(int)) );

    numimgs = new QSpinBox;
	numimgs -> setRange( 0, 50 );
	numimgs -> setSingleStep( 1 );
	// numimgs->setWrapping ( TRUE ); 
	connect( numimgs, SIGNAL(valueChanged(int)), spheres, SLOT(numImages(int)));

    anim = new QPushButton( tr("Anim") );
	anim->setCheckable( true );
    connect( anim, SIGNAL(stateChanged( int)), spheres, SLOT(animbutton(int)) );

	QBoxLayout * hvals1 = new QHBoxLayout;
	hvals1->addWidget( initang );
	hvals1->addWidget( stopang );
	hvals1->addWidget( whichAng );
	hvals1->addWidget( numimgs );
	hvals1->addWidget( anim );

	grid->addLayout( hvals1, 1, 1 );

	light_dis = new QSlider( Qt::Horizontal );
	light_dis -> setRange( 15, 100 );
	light_dis -> setSingleStep( 1 );
	light_dis -> setValue( 25 );
	
    connect(light_dis, SIGNAL(valueChanged( int)),spheres,SLOT(dist_slider(int)) );

	// QLabel * dist_label = new QLabel( this, "Dist_label" );
	QLabel * dist_label = new QLabel;
    connect(light_dis,SIGNAL(valueChanged(int)),dist_label,SLOT(setNum(int)) );

	QBoxLayout * hvals2 = new QHBoxLayout;
	hvals2->addWidget( light_dis );
	hvals2->addWidget( dist_label );
    grid->addLayout( hvals2, 2, 1 );

}

